@@ -9,24 +9,30 @@
 #' 
 #' `unit` is a character string describing the unit of measurement to be used for the legend title
 #'
+#' `layer` is the layer number to be plotted.
+#' 
+#' `timestamp` if TRUE (default) the plot title is the layer's date
+#'
 #' @import data.table ggplot2
 #' @importFrom grDevices dev.size
 #' @importFrom methods as setGeneric setMethod
 #' @importFrom raster as.data.frame brick
 #' @importFrom stats quantile
 #' @param x Raster* object; data.table (see details); filename (character, see details)
+#' @param layer numeric
 #' @param unit character
+#' @param timestamp logical
 #' @return ggplot object
 #' @export
 
-setGeneric("plot_map", function(x, unit = "mm") standardGeneric("plot_map"))
+setGeneric("plot_map", function(x, layer = 1, unit = "mm", timestamp = TRUE) standardGeneric("plot_map"))
 
 #' @rdname plot_map
 #' @method plot_map Raster
 
 setMethod("plot_map", "Raster",
-          function(x, unit = "mm") {
-            x <- x[[1]]
+          function(x, layer = 1, unit = "mm", timestamp = TRUE) {
+            x <- x[[layer]]
             x <- as.data.frame(x, xy = TRUE, long = TRUE, na.rm = TRUE) %>%
               as.data.table()
             setnames(x, c("lon", "lat", "date", "value"))
@@ -36,27 +42,26 @@ setMethod("plot_map", "Raster",
               map_expand <- TRUE
             }
             map_max <- quantile(x$value, 0.9995)
-            map_min <- round(min(x$value)) - 1 
-            if (map_min < 0){
-              map_min <- 0
+            x[value > map_max, value := map_max]
+            if (timestamp == TRUE) {
+              date_title <- format(as.Date(x$date[1]), "%B %Y")
+            } else {
+              date_title <- NULL
             }
-            x[value > map_max, value := map_max
-              ][value < map_min, value := map_min]
             p00 <- ggplot(x, aes(x = lon, y = lat)) +
               geom_raster(aes(fill = value)) +
-              borders(colour = "black") +
+              borders(colour = "gray23") +
               theme_bw() +
               coord_cartesian(xlim = c(min(x$lon), max(x$lon)), 
                               ylim = c(min(x$lat), max(x$lat)),
                               expand = map_expand) +
               labs(x = NULL, y = NULL, fill = paste0('[', unit, ']'),
-                   title = format(as.Date(x$date[1]), "%B %Y")) +
+                   title = date_title) +
               scale_fill_distiller(palette = "YlGnBu",
                                    direction = 1,
-                                   limits = c(map_min, map_max),
-                                   guide = guide_colorbar(frame.colour = "black",
-                                                          ticks.colour = "black")) +
-              theme(panel.border = element_rect(colour = "black",
+                                   guide = guide_colorbar(frame.colour = "gray23",
+                                                          ticks.colour = "gray23")) +
+              theme(panel.border = element_rect(colour = "gray23",
                                                 linewidth = 2),
                     panel.grid = element_blank(),
                     plot.tag = element_text(size = 24), 
@@ -74,34 +79,37 @@ setMethod("plot_map", "Raster",
 #' @method plot_map data.table
 
 setMethod("plot_map", "data.table",
-          function(x, unit = "mm") {
+          function(x, layer = 0, unit = "mm", timestamp = TRUE) {
+            if(layer >= 1) {
+              dummie_dates <- sort(unique(x$date))
+              x <- x[date == dummie_dates[layer]]
+            }
             if (round((max(x$lon) - min(x$lon))) == 360){
               map_expand <- FALSE
             } else {
               map_expand <- TRUE
             }
             map_max <- quantile(x$value, 0.9995)
-            map_min <- round(min(x$value)) - 1 
-            if (map_min < 0){
-              map_min <- 0
+            x[value > map_max, value := map_max]
+            if (timestamp == TRUE) {
+              date_title <- format(as.Date(x$date[1]), "%B %Y")
+            } else {
+              date_title <- NULL
             }
-            x[value > map_max, value := map_max
-              ][value < map_min, value := map_min]
             p00 <- ggplot(x, aes(x = lon, y = lat)) +
               geom_raster(aes(fill = value)) +
-              borders(colour = "black") +
+              borders(colour = "gray23") +
               theme_bw() +
               coord_cartesian(xlim = c(min(x$lon), max(x$lon)), 
                               ylim = c(min(x$lat), max(x$lat)),
                               expand = map_expand) +
               labs(x = NULL, y = NULL, fill = paste0('[', unit, ']'),
-                   title = format(as.Date(x$date[1]), "%B %Y")) +
+                   title = date_title) +
               scale_fill_distiller(palette = "YlGnBu",
                                    direction = 1,
-                                   limits = c(map_min, map_max),
-                                   guide = guide_colorbar(frame.colour = "black",
-                                                          ticks.colour = "black")) +
-              theme(panel.border = element_rect(colour = "black",
+                                   guide = guide_colorbar(frame.colour = "gray23",
+                                                          ticks.colour = "gray23")) +
+              theme(panel.border = element_rect(colour = "gray23",
                                                 linewidth = 2),
                     panel.grid = element_blank(),
                     plot.tag = element_text(size = 24), 
@@ -119,9 +127,9 @@ setMethod("plot_map", "data.table",
 #' @method plot_map character
 
 setMethod("plot_map", "character",
-          function(x, unit = "mm") {
+          function(x, layer = 1, unit = "mm", timestamp = TRUE) {
             x <- brick(x)
-            x <- x[[1]]
+            x <- x[[layer]]
             x <- as.data.frame(x, xy = TRUE, long = TRUE, na.rm = TRUE) %>%
               as.data.table()
             setnames(x, c("lon", "lat", "date", "value"))
@@ -131,27 +139,26 @@ setMethod("plot_map", "character",
               map_expand <- TRUE
             }
             map_max <- quantile(x$value, 0.9995)
-            map_min <- round(min(x$value)) - 1 
-            if (map_min < 0){
-              map_min <- 0
+            x[value > map_max, value := map_max]
+            if (timestamp == TRUE) {
+              date_title <- format(as.Date(x$date[1]), "%B %Y")
+            } else {
+              date_title <- NULL
             }
-            x[value > map_max, value := map_max
-              ][value < map_min, value := map_min]
             p00 <- ggplot(x, aes(x = lon, y = lat)) +
               geom_raster(aes(fill = value)) +
-              borders(colour = "black") +
+              borders(colour = "gray23") +
               theme_bw() +
               coord_cartesian(xlim = c(min(x$lon), max(x$lon)), 
                               ylim = c(min(x$lat), max(x$lat)),
                               expand = map_expand) +
               labs(x = NULL, y = NULL, fill = paste0('[', unit, ']'),
-                   title = format(as.Date(x$date[1]), "%B %Y")) +
+                   title = date_title) +
               scale_fill_distiller(palette = "YlGnBu",
                                    direction = 1,
-                                   limits = c(map_min, map_max),
-                                   guide = guide_colorbar(frame.colour = "black",
-                                                          ticks.colour = "black")) +
-              theme(panel.border = element_rect(colour = "black",
+                                   guide = guide_colorbar(frame.colour = "gray23",
+                                                          ticks.colour = "gray23")) +
+              theme(panel.border = element_rect(colour = "gray23",
                                                 linewidth = 2),
                     panel.grid = element_blank(),
                     plot.tag = element_text(size = 24), 
